decode_timestamp

Function decode_timestamp 

pub fn decode_timestamp(
    data: &[u8],
    offset: usize,
    tag_number: u8,
) -> Result<(BACnetTimeStamp, usize), Error>
Decode a BACnetTimeStamp from inside a context opening/closing tag pair.

data should point to the start of the outer opening tag for tag_number. Returns the decoded timestamp and the new offset past the outer closing tag.